@@ -1,4 +1,6 @@
-from ojtest import rand_list as rl, rand_str as rs
+from ojtest import (rand_list as rl,
+                    rand_str as rs,
+                    rand_tree as rt)
 
 rand_int_list = rl.rand_int_list
 rand_int_list_unique = rl.rand_int_list_unique
@@ -10,4 +12,6 @@ rand_str = rs.rand_str
 rand_str_alphabetic_lower = rs.rand_str_alphabetic_lower
 rand_str_alphabetic_capital = rs.rand_str_alphabetic_capital
 rand_str_alphabetic = rs.rand_str_alphabetic
-rand_str_digital = rs.rand_str_digital
\ No newline at end of file
+rand_str_digital = rs.rand_str_digital
+
+rand_tree = rt.rand_tree
\ No newline at end of file
